const libs = `${process.cwd()}/libs`;
const log = require(`${libs}/log`)(module);
const execQuery = require(`${libs}/db/query_exec`);
const jsonexport = require('jsonexport');
const fs = require('fs');

module.exports = function(agenda) {
    agenda.define('download database', (job, done) => {
        let sql = job.attrs.data.sql;
        execQuery(sql.text, sql.values).then((result) => {
            log.debug('Got results');
            jsonexport(result, (err, csv) => {
                if(err) {
                    log.error('Error converting to CSV');
                    log.error(err);
                    return done(err);
                }
                log.debug('Converted to csv');
                fs.writeFile('out.csv', csv, (err) => {
                    if(err) {
                        log.error('Error writing file');
                        log.error(err);
                        return done(err);
                    }
                    log.info('File created');
                    done();
                });
            });
        }, (err) => {
            log.error('Error getting data from database!');
            log.error(err);
            return done(err);
        });
    });
}
